import { Component, OnInit } from '@angular/core';
import { MatAnchor } from '@angular/material/button';
import { MatIcon } from '@angular/material/icon';
import { MatToolbar } from '@angular/material/toolbar';
import { EventType, Router, RouterLink } from '@angular/router';

@Component({
    selector: 'app-header',
    imports: [
        MatToolbar,
        MatAnchor,
        RouterLink,
        MatIcon,
    ],
    templateUrl: './header.component.html',
    styleUrl: './header.component.scss'
})
export class HeaderComponent implements OnInit {
    routes: Array<{ path: string, title: string, class: string }> = [];

    constructor(
        private router: Router,
    ) {
    }

    ngOnInit(): void {
        const routes = this.router.config
            .filter(route => !route.path?.includes(':'))
            .filter(route => !route.path?.includes('/'));

        this.router.events.subscribe((event) => {
            if (event.type != EventType.NavigationEnd) {
                return;
            }
            this.routes = routes.map(route => ({
                path: `/${route.path}`,
                title: route.title as string,
                class: `/${route.path}` == event.url ? 'active' : ''
            }));
        });
    }
}
