import {Component} from '@angular/core';
import {FormBuilder, FormGroup, FormsModule, ReactiveFormsModule} from '@angular/forms';
import {MatButtonModule} from '@angular/material/button';
import {MatFormFieldModule} from '@angular/material/form-field';
import {MatInputModule} from '@angular/material/input';
import {MatSelectModule} from '@angular/material/select';
import {NotificationService, NotificationType} from '@core/notification/notification.service';
import {PlayerRegistrationData, ServerService} from '@core/server';

@Component({
    selector: 'app-registration-form',
    imports: [MatFormFieldModule, FormsModule, MatSelectModule, MatInputModule, MatButtonModule, ReactiveFormsModule],
    templateUrl: './registration-form.component.html',
    styleUrl: './registration-form.component.scss',
    standalone: true
})
export class RegistrationFormComponent {
    registrationForm: FormGroup;


    constructor(private serverApi: ServerService, private formBuilder: FormBuilder, private notifications: NotificationService) {
        this.registrationForm = this.formBuilder.group<PlayerRegistrationData>({
            username: '',
            password: '',
        });
        //this.registrationForm.addValidators(isEmpty);
    }

    registerPlayer() {
        if (!this.registrationForm.valid) {
            this.notifications.publish('This form is invalid!', NotificationType.Error);
            return;
        }
        this.serverApi
            .playerRegister(this.registrationForm.value)
            .subscribe((response) => {
                console.log(response);
            });
    }

}
